Tooltipster
===========

A jQuery tooltip plugin by Caleb Jacob under MIT license.  
Compatible with Mozilla Firefox, Google Chrome, IE8+ and others. Requires jQuery 1.7+

A reminder of options/methods lies below. For detailed documentation, visit http://iamceege.github.io/tooltipster/

Options
-------------------------

animation  
arrow  
arrowColor  
autoClose  
content  
contentAsHTML  
contentCloning  
debug  
delay  
minWidth  
maxWidth  
functionInit  
functionBefore  
functionReady  
functionAfter  
hideOnClick  
icon  
iconCloning  
iconDesktop  
iconTheme  
iconTouch  
interactive  
interactiveTolerance  
multiple  
offsetX  
offsetY  
onlyOne  
position  
positionTracker  
positionTrackerCallback  
restoration  
speed  
timer  
theme  
touchDevices  
trigger  
updateAnimation  

Methods
-------------------------

$.fn.tooltipster('setDefaults', {})  
$(...).tooltipster('show' [, callback])  
$(...).tooltipster('hide' [, callback])  
$(...).tooltipster('disable')  
$(...).tooltipster('enable')  
$(...).tooltipster('destroy')  
$(...).tooltipster('content')  
$(...).tooltipster('content', myNewContent)  
$(...).tooltipster('option', optionName)  
$(...).tooltipster('option', optionName, optionValue)  
$(...).tooltipster('reposition')  
$(...).tooltipster('elementTooltip')  
$(...).tooltipster('elementIcon')  